Learn R Programming

sandwich (version 1.1-1)

meat: A Simple Meat Matrix Estimator

Description

Estimating the variance of the estimating functions of a regression model by cross products of the empirical estimating functions.

Usage

meat(x, adjust = FALSE, ...)

Arguments

x
a fitted model object.
adjust
logical. Should a finite sample adjustment be made? This amounts to multiplication with $n/(n-k)$ where $n$ is the number of observations and $k$ the number of estimated parameters.
...
arguments passed to the estfun function.

Value

  • A $$k \times k$$ matrix corresponding containing the scaled cross products of the empirical estimating functions.

Details

For some theoretical background along with implementation details see Zeileis (2006).

References

Zeileis A (2006), Object-oriented Computation of Sandwich Estimators. Package vignette.

See Also

sandwich, bread, estfun

Examples

Run this code
x <- sin(1:10)
y <- rnorm(10)
fm <- lm(y ~ x)

meat(fm)
meatHC(fm, type = "HC")
meatHAC(fm)

Run the code above in your browser using DataLab