When type = "const" constant variances are assumed and
and covHC gives the usual estimate of the covariance matrix of
the coefficient estimates: $$\hat \sigma^2 (X^\top X)^{-1}$$
All other methods do not assume constant variances and are suitable in case of
heteroskedasticity. "HC" (or equivalently "HC0") gives White's
estimator, the other estimators are refinements of this. They are all of form
$$(X^\top X)^{-1} X^\top \Omega X (X^\top X)^{-1}$$
and differ in the choice of Omega. This is in all cases a diagonal matrix whose
elements are function of the residuals, the diagonal elements of the hat matrix and
the residual degrees of freedom. For White's estimator
omega <- function(residuals, diaghat, df) residuals^2
Instead of specifying a type the argument omega can also be specified
directly. For details see the references.